@@ -10,7 +10,7 @@ use Perinci::Exporter;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-05-06'; # DATE
 our $DIST = 'App-ImageMagickUtils'; # DIST
-our $VERSION = '0.013'; # VERSION
+our $VERSION = '0.014'; # VERSION
 
 our %SPEC;
 
@@ -30,11 +30,35 @@ our %argspec0_files = (
     },
 );
 
-our %argspecopt_delete_original = (
+our %argspecs_delete = (
     delete_original => {
+        summary => 'Delete (unlink) the original file after downsizing',
         schema => 'bool*',
+        description => <<'_',
+
+See also the `trash_original` option.
+
+_
         cmdline_aliases => {D=>{}},
     },
+    trash_original => {
+        summary => 'Trash the original file after downsizing',
+        schema => 'bool*',
+        description => <<'_',
+
+This option uses the <pm:File::Trash::FreeDesktop> module to do the trashing.
+Compared to deletion, with this option you can still restore the trashed
+original files from the Trash directory.
+
+See also the `delete_original` option.
+
+_
+        cmdline_aliases => {T=>{}},
+    },
+);
+
+our %args_rels = (
+    choose_one => [qw/delete_original trash_original/],
 );
 
 sub _nearest {
@@ -79,12 +103,13 @@ _
             cmdline_aliases => {
                 dont_downsize => {summary=>"Alias for --downsize-to ''", is_flag=>1, code=>sub {$_[0]{downsize_to} = ''}},
                 no_downsize   => {summary=>"Alias for --downsize-to ''", is_flag=>1, code=>sub {$_[0]{downsize_to} = ''}},
-                1536          => {summary=>"Shortcut for --downsize-to=1536", code=>sub {$_[0]{downsize_to} = '1536'}},
-                2048          => {summary=>"Shortcut for --downsize-to=2048", code=>sub {$_[0]{downsize_to} = '2048'}},
+                1536          => {summary=>"Shortcut for --downsize-to=1536", is_flag=>1, code=>sub {$_[0]{downsize_to} = '1536'}},
+                2048          => {summary=>"Shortcut for --downsize-to=2048", is_flag=>1, code=>sub {$_[0]{downsize_to} = '2048'}},
             },
         },
-        %argspecopt_delete_original,
+        %argspecs_delete,
     },
+    args_rels => \%args_rels,
     features => {
         dry_run => 1,
     },
@@ -122,6 +147,7 @@ sub downsize_image {
     }
 
     my ($num_files, $num_success) = (0, 0);
+    my $trash;
     for my $file (@{$args{files}}) {
         log_info "Processing file %s ...", $file;
         $num_files++;
@@ -177,7 +203,12 @@ sub downsize_image {
             my ($exit_code, $signal, $core_dump) = ($? < 0 ? $? : $? >> 8, $? & 127, $? & 128);
             log_error "convert for $file failed: exit_code=$exit_code, signal=$signal, core_dump=$core_dump";
         } else {
-            if ($args{delete_original}) {
+            if ($args{trash_original}) {
+                require File::Trash::FreeDesktop;
+                $trash //= File::Trash::FreeDesktop->new;
+                # will die upon failure, currently we don't trap
+                $trash->trash($file);
+            } elsif ($args{delete_original}) {
                 # currently we ignore the results
                 log_trace "Deleting original file %s ...", $file;
                 unlink $file;
@@ -211,7 +242,7 @@ _
             req => 1,
             examples => [qw/pdf jpg png/], # for tab completion
         },
-        %argspecopt_delete_original,
+        %argspecs_delete,
     },
     #features => {
     #    dry_run => 1,
@@ -232,6 +263,7 @@ sub convert_image_to {
     my $to = $args{to} or return [400, "Please specify target format in `to`"];
 
     my $envres = Perinci::Object::envresmulti();
+    my $trash;
     for my $file (@{$args{files}}) {
         log_info "Processing file %s ...", $file;
         IPC::System::Options::system(
@@ -242,7 +274,12 @@ sub convert_image_to {
 
         if ($ps->is_success) {
             $envres->add_result(200, "OK", {item_id=>$file});
-            if ($args{delete_original}) {
+            if ($args{trash_original}) {
+                require File::Trash::FreeDesktop;
+                $trash //= File::Trash::FreeDesktop->new;
+                # will die upon failure, currently we don't trap
+                $trash->trash($file);
+            } elsif ($args{delete_original}) {
                 # currently we ignore the result of deletion
                 log_trace "Deleting original file %s ...", $file;
                 unlink $file;
@@ -274,7 +311,7 @@ which in turn is equivalent to:
 _
     args => {
         %argspec0_files,
-        %argspecopt_delete_original,
+        %argspecs_delete,
     },
     #features => {
     #    dry_run => 1,
@@ -305,7 +342,7 @@ App::ImageMagickUtils - Utilities related to ImageMagick
 
 =head1 VERSION
 
-This document describes version 0.013 of App::ImageMagickUtils (from Perl distribution App-ImageMagickUtils), released on 2022-05-06.
+This document describes version 0.014 of App::ImageMagickUtils (from Perl distribution App-ImageMagickUtils), released on 2022-05-06.
 
 =head1 DESCRIPTION
 
@@ -355,10 +392,24 @@ Arguments ('*' denotes required arguments):
 
 =item * B<delete_original> => I<bool>
 
+Delete (unlink) the original file after downsizing.
+
+See also the C<trash_original> option.
+
 =item * B<files>* => I<array[filename]>
 
 =item * B<to>* => I<str>
 
+=item * B<trash_original> => I<bool>
+
+Trash the original file after downsizing.
+
+This option uses the L<File::Trash::FreeDesktop> module to do the trashing.
+Compared to deletion, with this option you can still restore the trashed
+original files from the Trash directory.
+
+See also the C<delete_original> option.
+
 
 =back
 
@@ -403,8 +454,22 @@ Arguments ('*' denotes required arguments):
 
 =item * B<delete_original> => I<bool>
 
+Delete (unlink) the original file after downsizing.
+
+See also the C<trash_original> option.
+
 =item * B<files>* => I<array[filename]>
 
+=item * B<trash_original> => I<bool>
+
+Trash the original file after downsizing.
+
+This option uses the L<File::Trash::FreeDesktop> module to do the trashing.
+Compared to deletion, with this option you can still restore the trashed
+original files from the Trash directory.
+
+See also the C<delete_original> option.
+
 
 =back
 
@@ -451,6 +516,10 @@ Arguments ('*' denotes required arguments):
 
 =item * B<delete_original> => I<bool>
 
+Delete (unlink) the original file after downsizing.
+
+See also the C<trash_original> option.
+
 =item * B<downsize_to> => I<str> (default: 1024)
 
 Downsizing will only be done if the input image's shortest side is indeed larger
@@ -463,6 +532,16 @@ C<--dont-downsize> on the CLI.
 
 =item * B<q> => I<int> (default: 40)
 
+=item * B<trash_original> => I<bool>
+
+Trash the original file after downsizing.
+
+This option uses the L<File::Trash::FreeDesktop> module to do the trashing.
+Compared to deletion, with this option you can still restore the trashed
+original files from the Trash directory.
+
+See also the C<delete_original> option.
+
 
 =back
 
